hive-build.collect.io

Filesystem, environment and registry reads.

Every function here is one effect and no decision, so everything above this layer can be pure. Nothing in here interprets what it reads.

Filesystem, environment and registry reads.

Every function here is one effect and no decision, so everything above this
layer can be pure. Nothing in here interprets what it reads.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries