Filesystem, environment and registry reads.
Every function here is one effect and no decision, so everything above this layer can be pure. Nothing in here interprets what it reads.
Filesystem, environment and registry reads. Every function here is one effect and no decision, so everything above this layer can be pure. Nothing in here interprets what it reads.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |